==> libavg_0.7.0.orig.tar.gz: libavg-0.7.0/src/imaging/FWCameraUtils.h <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2006 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#ifndef _FWCameraUtils_H_
#define _FWCameraUtils_H_

#include "../avgconfigwrapper.h"

#include "../base/Point.h"

#ifdef AVG_ENABLE_1394
#include <libraw1394/raw1394.h>
#include <libdc1394/dc1394_control.h>
#endif
#ifdef AVG_ENABLE_1394_2
#include <dc1394/control.h>
#endif

#include <string>

namespace avg {

#ifdef AVG_ENABLE_1394
int getCamMode(IntPoint Size, std::string sPF);
int getFrameRateConst(double FrameRate);
int getFeatureID(const std::string& sFeature);
#else
dc1394video_mode_t getCamMode(IntPoint Size, std::string sPF);
dc1394framerate_t getFrameRateConst(double FrameRate);
dc1394feature_t getFeatureID(const std::string& sFeature);
#endif


}

#endif

==> libavg_0.8.0.orig.tar.gz: libavg-0.8.0/src/imaging/FWCameraUtils.h <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2008 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#ifndef _FWCameraUtils_H_
#define _FWCameraUtils_H_

#include "Camera.h"

#include "../avgconfigwrapper.h"

#include "../base/Point.h"

#ifdef AVG_ENABLE_1394
#include <libraw1394/raw1394.h>
#include <libdc1394/dc1394_control.h>
#endif
#ifdef AVG_ENABLE_1394_2
#include <dc1394/control.h>
#endif

#include <string>

namespace avg {

#ifdef AVG_ENABLE_1394
int getCamMode(IntPoint Size, std::string sPF);
int getFrameRateConst(double FrameRate);
int getFeatureID(CameraFeature Feature);
#else
dc1394video_mode_t getCamMode(IntPoint Size, std::string sPF);
dc1394framerate_t getFrameRateConst(double FrameRate);
dc1394feature_t getFeatureID(CameraFeature Feature);
#endif


}

#endif
